==> maven_3.6.3.orig.tar.xz: maven-maven-3.6.3/maven-core/src/test/java/org/apache/maven/repository/TestArtifactHandler.java <==
package org.apache.maven.repository;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.artifact.handler.ArtifactHandler;

/**
 * Assists unit testing.
 *
 * @author Benjamin Bentmann
 */
class TestArtifactHandler
    implements ArtifactHandler
{

    private String type;

    private String extension;

    public TestArtifactHandler( String type )
    {
        this( type, type );
    }

    public TestArtifactHandler( String type, String extension )
    {
        this.type = type;
        this.extension = extension;
    }

    public String getClassifier()
    {
        return null;
    }

    public String getDirectory()
    {
        return getPackaging() + "s";
    }

    public String getExtension()
    {
        return extension;
    }

    public String getLanguage()
    {
        return "java";
    }

    public String getPackaging()
    {
        return type;
    }

    public boolean isAddedToClasspath()
    {
        return true;
    }

    public boolean isIncludesDependencies()
    {
        return false;
    }

}

==> maven_3.9.9.orig.tar.xz: maven-maven-3.9.9/maven-core/src/test/java/org/apache/maven/repository/TestArtifactHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.repository;

import org.apache.maven.artifact.handler.ArtifactHandler;

/**
 * Assists unit testing.
 *
 * @author Benjamin Bentmann
 */
class TestArtifactHandler implements ArtifactHandler {

    private String type;

    private String extension;

    public TestArtifactHandler(String type) {
        this(type, type);
    }

    public TestArtifactHandler(String type, String extension) {
        this.type = type;
        this.extension = extension;
    }

    public String getClassifier() {
        return null;
    }

    public String getDirectory() {
        return getPackaging() + "s";
    }

    public String getExtension() {
        return extension;
    }

    public String getLanguage() {
        return "java";
    }

    public String getPackaging() {
        return type;
    }

    public boolean isAddedToClasspath() {
        return true;
    }

    public boolean isIncludesDependencies() {
        return false;
    }
}
